#include <haskell2c.h>
#include "cLowUnboxedArray.h"
#include <stdlib.h>

void * hs_allocUBA (int size,unsigned int end)
{ UBA uba;
  
   uba = (UBA)malloc(sizeof(struct UnboxedArray));
   uba->block = (unsigned*)malloc(size*sizeof(unsigned));
   uba->free  = size;
   uba->write = 0;
   uba->end   = end;
  return nhc_mkCInt((int)allocForeignObj((void*)uba,(gcCval)finaliseUBA,gcNow));
}
